<template>
  <div style="width: 100%;">
    <a-card :bordered="false">
      <!-- 查询区域 -->
      <div class="table-page-search-wrapper">
        <a-form layout="inline" @keyup.enter.native="searchQuery">
          <a-row :gutter="24">
            <a-col :md="6" :sm="6">
              <a-form-item label="时间">
                <a-range-picker @change="dateParamChange" :disabledDate="disabledDate" format="YYYYMMDD" v-model="dates"/>
              </a-form-item>
            </a-col>
            <a-col :lg="3" :md="3" :sm="3" :xs="3">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
            </a-col>
            <a-col :lg="3"  :md="3" :sm="3" :xs="3">
              <a-button type="primary" @click="searchReset" icon="reload">重置</a-button>
            </a-col>
            <a-col :lg="3" :md="3" :sm="3" :xs="3">
              <a-button type="primary" @click="exportExcel" icon="download">导出</a-button>
            </a-col>
          </a-row>
          <a-row :gutter="24">
            <a-col :md="15" :sm="15">
              <a-checkbox-group :value="checkedList" :default-value="['lyl']" :options="efficiencyOptions"
                                @change="efficiencyOptionsOnChange"/>
            </a-col>
          </a-row>
        </a-form>
      </div>
      <div style="width: 400px;position: absolute;top: 20px; right: 0px;">
        <table cellpadding="5" cellspacing="1" style="border: 1px solid darkgray;">
          <tr>
            <td v-for="(item, index) in identifying">{{item.title}}</td>
          </tr>
          <tr>
            <td style="text-align:center;" v-for="(item, index) in identifying">
              <div class="identifyingclass" :style="{background: item.color}"></div>
            </td>
            <!--<td style="text-align:center;"><div style="width: 55px;height: 15px;background-color: #e8ff37;display:inline-block"></div></td>-->
            <!--<td style="text-align:center;"><div style="width: 55px;height: 15px;background-color: #99ff4e;display:inline-block"></div></td>-->
          </tr>
        </table>
      </div>
      <div class="container" id="EfficiencyPO" style="margin-top: 20px;">
        <div class="table2">
          <table class="dataContent table" border="1" cellspacing="0" cellpadding="0" style="white-space: nowrap">
            <thead>
            <tr class="thead fixed equipname">
              <th class="thgu dong1 name" rowspan="2" style="min-width: 100px; max-width: 100px;width: 100px;">设备编号</th>
              <th class="thgu dong2 name" rowspan="2" style="min-width: 150px; max-width: 150px;width: 150px;">设备名称</th>
              <th class="thgu dong3 name" rowspan="2" style="min-width: 100px; max-width: 100px;width: 100px;">设备类型</th>
              <!--<th rowspan="2">组别</th>-->
              <template v-for="(tableHead, index) in tableHeads">
                <th class="timeth" :colspan="checkedList.length">{{tableHead}}</th>
              </template>
            </tr>
            <tr class="thead notfixed gudingth">
              <template v-for="(tableHead, index) in tableHeads">
                <th>开动率(%)</th>
                <th v-if="checkedList.indexOf('kjl') > -1">开机率(%)</th>
                <th v-if="checkedList.indexOf('kjsj') > -1">开机时间(s)</th>
                <th v-if="checkedList.indexOf('jgsj') > -1">加工时间(s)</th>
                <th v-if="checkedList.indexOf('djsj') > -1">待机时间(s)</th>
                <th v-if="checkedList.indexOf('gjsj') > -1">关机时间(s)</th>
              </template>
            </tr>
            </thead>
            <tbody>
            <tr class="mathData" v-for="(item, index) in dataList">
              <td class="tdgu  kaitou">{{item.equipmentId}}</td>
              <td class="tdgu1  kaitou">{{item.equipmentName}}</td>
              <td class="tdgu2  kaitou">{{item.equipmentType}}</td>
              <!--<td>{{item.tierType}}</td>-->
              <template v-for="(tableHead, index) in tableHeads">
                <td :style="{background:item[tableHead].color }">{{item[tableHead].lyl | numFilter}}</td>
                <td :style="{background:item[tableHead].color }" v-if="checkedList.indexOf('kjl') > -1">
                  {{item[tableHead].kjl | numFilter}}
                </td>
                <td :style="{background:item[tableHead].color }" v-if="checkedList.indexOf('kjsj') > -1">
                  {{item[tableHead].kjsj}}
                </td>
                <td :style="{background:item[tableHead].color }" v-if="checkedList.indexOf('jgsj') > -1">
                  {{item[tableHead].jgsj}}
                </td>
                <td :style="{background:item[tableHead].color }" v-if="checkedList.indexOf('djsj') > -1">
                  {{item[tableHead].djsj}}
                </td>
                <td :style="{background:item[tableHead].color }" v-if="checkedList.indexOf('gjsj') > -1">
                  {{item[tableHead].gjsj}}
                </td>
              </template>
            </tr>
            </tbody>
          </table>
        </div>
      </div>
    </a-card>
  </div>
</template>

<script>
import moment from 'moment'
import { putAction, getAction } from '@/api/manage'
import $ from 'jquery'
import '@/components/table2excel/table2excel'
import { ajaxGetDictItems, getDictItemsFromCache, duplicateCheck } from '@/api/api'
export default {
  name: 'EfficiencyPOList',
  components: {},
  data() {
    return {
      typeTree:"",
      typeParent:1,
      typeEquipment:1,
      dates: [],
      queryParam: {},
      queryParamEquip:{},
      queryParamPeople:{},
      identifying: [],
      efficiencyOptions: [
        { label: '开动率', value: 'lyl' },
        { label: '开机率', value: 'kjl' },
        { label: '开机时间', value: 'kjsj' },
        { label: '加工时间', value: 'jgsj' },
        { label: '待机时间', value: 'djsj' },
        { label: '关机时间', value: 'gjsj' }
      ],
      checkedList: ['lyl'],
      dataList: [],
      url: {
        list: '/mdc/efficiencyReport/efficiencyPOList',
        listByType: '/mdc/MdcUtilizationRate/listByType'
      },
      tableHeads: []
    }
  },
  props: { nodeTree: '', Type:'',nodePeople: ''},
  created() {
    this.showIdentifying()
    this.dates = [moment().subtract('days', 8), moment().subtract('days', 1)]
    this.queryParam.startTime = moment(this.dates[0]).format('YYYYMMDD')
    this.queryParam.endTime = moment(this.dates[1]).format('YYYYMMDD')
    this.queryParam.typeTree = "1"
    this.loadData()
  },
  watch: {
    Type(valmath){
      this.dataList = [];
      this.queryParam.typeTree = valmath
    },
    nodeTree(val) { //监听currSelected 变化，将变化后的数值传递给 getCurrSelected 事件
      if (JSON.stringify(val) != '{}') {
        if (val.entity.equipmentId) {
          this.queryParamEquip.parentId = ''
          this.queryParamEquip.equipmentIds = val.entity.equipmentId
        } else {
          this.queryParamEquip.parentId = val.entity.id
          this.queryParamEquip.equipmentIds = ''
        }
        this.searchQuery()
      }
    },
    nodePeople(val){
      if (JSON.stringify(val) != '{}') {
        if (val.entity.equipmentId) {
          this.queryParamPeople.parentId = val.entity.equipmentId
          this.queryParamPeople.equipmentIds = ''
        } else {
          this.queryParamPeople.parentId = val.entity.id
          this.queryParamPeople.equipmentIds = ''
        }
        this.searchQuery()
      }
    }
  },
  filters: {
    numFilter(value) {
      if (value) {
        return parseFloat((value * 100).toFixed(2))
      } else {
        return '0'
      }
    }
  },
  methods: {
    disabledDate(current){
      //Can not slect days before today and today
      return current && current > moment().subtract('days', 1);
    },
    initDeviceType(deviceList) {
      let dictCode = 'mdc_equipmentType'
      let items = []
      items = getDictItemsFromCache(dictCode)
      if (deviceList && items.length > 0) {
        for (let a = 0; a < deviceList.length; a++) {
          if (items && items.length > 0) {
            for (let i = 0; i < items.length; i++) {
              if (deviceList[a].equipmentType == items[i].value) {
                deviceList[a].equipmentType = items[i].title
              }
            }
          } else {
            ajaxGetDictItems(dictCode, null).then((res) => {
              if (res.success) {
                let items = res.result
                for (let i = 0; i < items.length; i++) {
                  if (deviceList[a].equipmentType == items[i].value) {
                    deviceList[a].equipmentType = items[i].title
                  }
                }
              }
            })
          }
        }
      }
    },
    exportExcel() {
      $("#EfficiencyPO").table2excel({
        exclude: ".noExl",
        name: "Excel Document Name",
        filename: "设备开动率",
        exclude_img: true,
        fileext: ".xls",
        exclude_links: true,
        exclude_inputs: true
      });
    },
    showIdentifying() {
      getAction(this.url.listByType, { type: 'kdl' }).then(res => {
        if (res.success) {
          this.identifying = res.result
        }
      })
    },
    dateParamChange(v1, v2) {
      this.queryParam.startTime = v2[0]
      this.queryParam.endTime = v2[1]
    },
    efficiencyOptionsOnChange(checkedList) {
      let index = checkedList.indexOf('lyl')
      if (index < 0) {
        this.$message.warn('不能取消查询利用率')
        return false
      }
      this.checkedList = checkedList
    },
    searchQuery() {
      if(this.queryParam.typeTree == "1"){
        this.queryParam.parentId =  this.queryParamEquip.parentId
        this.queryParam.equipmentIds = this.queryParamEquip.equipmentIds
      }else{
        this.queryParam.parentId = this.queryParamPeople.parentId
        this.queryParam.equipmentIds = ""
      }
      this.loadData()
      // this.onClearSelected()
    },
    searchReset() {
      this.typeTree = this.queryParam.typeTree
      this.typeParent =  this.queryParam.parentId
      this.typeEquipment = this.queryParam.equipmentIds
      this.queryParam = {}
      this.dates = []
      this.queryParam.typeTree = this.typeTree
      this.queryParam.parentId = this.typeParent
      this.queryParam.equipmentIds =  this.typeEquipment
      // this.ipagination.current = 1
      this.loadData();
      // this.queryParam = {}
      // this.dates = []
      // this.loadData()
      // this.onClearSelected()
    },
    loadData() {
      console.log(this.queryParam)
      getAction(this.url.list, this.queryParam).then(res => {
        if (res.success) {
          console.log(res.result)
          this.tableHeads = res.result.dates
          this.dataList = res.result.list
          this.initDeviceType(this.dataList)
        }
      })
    }
  }
}
</script>
<style scoped>
/*table样式*/
.table2{
  width: 100%;
  height: 100%;
  overflow: auto;
}
.table2 thead tr th:first-child,
.table tbody tr .tdgu{
  position: sticky;
  left: 0;
  z-index: 1;
}
.table tbody tr .kaitou{
  z-index: 1;
  background-color: white;
}
.table tbody tr .tdgu1{
  position: sticky;
  left: 100px;
  z-index: 2;
}
.table tbody tr .tdgu2{
  position: sticky;
  left: 250px;
  z-index: 2;
}
.table2 thead tr .timeth,
.table2 thead tr  .thgu {
  position: sticky;
  top:0;
  z-index: 3;
}
.table2 thead .gudingth th{
  position: sticky;
  top: 32px;
  z-index: 2;
}
.table2 thead .equipname .name{
  z-index: 3;
}
.table2 thead .equipname .dong1{
  z-index: 4;
  left: 0;
  /*border: 1px solid #000;*/
}
.table2 thead .equipname .dong2{
  z-index: 5;
  left: 100px;
}
.table2 thead .equipname .dong3{
  z-index: 5;
  left: 250px;
}



@media screen and (min-width: 1920px){
  #EfficiencyPO{
    height: 687px!important;
    overflow: scroll;
  }
}
@media screen and (min-width: 1680px) and (max-width: 1920px){
  #EfficiencyPO{
    height: 687px!important;
    overflow: scroll;
  }
}
@media screen and (min-width: 1400px) and (max-width: 1680px){
  #EfficiencyPO{
    height: 540px!important;
    overflow: scroll;
  }
}
@media screen and (min-width: 1280px) and (max-width: 1400px){
  #EfficiencyPO{
    height: 440px!important;
    overflow: scroll;
  }
}
@media screen and (max-width: 1280px){
  #EfficiencyPO{
    height: 440px!important;
    overflow: scroll;
  }
}
.identifyingclass {
  width: 55px;
  height: 15px;
  display: inline-block
}
.dataContent {
  white-space: nowrap;
  /*margin: 0;*/
  border: none;
  border-collapse: separate;
  border-spacing: 0;
  /*table-layout: fixed;*/
  border: 1px solid #ccc;
  /*border: 1px solid #ccc;*/
  width: 100%;
  /*height: 100%;*/
  /*overflow: hidden;*/
  /*overflow-y: auto;*/
  text-align: center;
}

.dataContent .fixed th {
  width: 50px;
}

.dataContent .thead th {
  background-color: #fafafa;
  text-align: center;
  height: 30px;
  padding: 5px;
}

.dataContent .notfixed th {
  width: auto;
}

.dataContent tr td {
  height: 35px;
}

.dataContent .mathData td {
  padding: 10px;
  /*display: none;*/
}

.dataContent .mathData .td {
  /*background-color: #ff9bd2;*/
  display: inline-block;
  padding: 10px;
}

.dataContent .mathData .tdd {
  /*display: none;*/
}

</style>